Fleet Metrics Series
--------------------

Aggregated from :ref:`Fleet Metrics Vessels`

.. note::
    available on platforms : Platform.Liquids, Platform.LPG, Platform.LNG

.. autoclass:: kpler.sdk.resources.fleet_metrics.FleetMetrics
    :members:

.. autoclass:: kpler.sdk.FleetMetricsAlgo
    :members:

.. autoclass:: kpler.sdk.FleetMetricsPeriod
    :members:

.. autoclass:: kpler.sdk.FleetMetricsMeasurementUnit
    :members:

.. autoclass:: kpler.sdk.FleetMetricsSplit
    :members:

.. autoclass:: kpler.sdk.VesselTypesCPP
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLNG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLPG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesOil
    :members:
    :noindex: